Class: Google::Apis::SpeechV1p1beta1::RecognitionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/speech_v1p1beta1/classes.rb,
lib/google/apis/speech_v1p1beta1/representations.rb,
lib/google/apis/speech_v1p1beta1/representations.rb

Overview

Provides information to the recognizer that specifies how to process the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RecognitionConfig

Returns a new instance of RecognitionConfig.



981
982
983
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 981

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptationGoogle::Apis::SpeechV1p1beta1::SpeechAdaptation

Speech adaptation configuration. Corresponds to the JSON property adaptation



787
788
789
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 787

def adaptation
  @adaptation
end

#alternative_language_codesArray<String>

A list of up to 3 additional BCP-47 language tags, listing possible alternative languages of the supplied audio. See Language Support for a list of the currently supported language codes. If alternative languages are listed, recognition result will contain recognition in the most likely language detected including the main language_code. The recognition result will include the language tag of the language detected in the audio. Note: This feature is only supported for Voice Command and Voice Search use cases and performance may vary for other use cases (e.g., phone call transcription). Corresponds to the JSON property alternativeLanguageCodes

Returns:

  • (Array<String>)


801
802
803
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 801

def alternative_language_codes
  @alternative_language_codes
end

#audio_channel_countFixnum

The number of channels in the input audio data. ONLY set this for MULTI- CHANNEL recognition. Valid values for LINEAR16, OGG_OPUS and FLAC are 1-8. Valid value for MULAW, AMR, AMR_WB and SPEEX_WITH_HEADER_BYTE is only 1. If 0 or omitted, defaults to one channel (mono). Note: We only recognize the first channel by default. To perform independent recognition on each channel set enable_separate_recognition_per_channel to 'true'. Corresponds to the JSON property audioChannelCount

Returns:

  • (Fixnum)


811
812
813
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 811

def audio_channel_count
  @audio_channel_count
end

#diarization_configGoogle::Apis::SpeechV1p1beta1::SpeakerDiarizationConfig

Config to enable speaker diarization. Corresponds to the JSON property diarizationConfig



816
817
818
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 816

def diarization_config
  @diarization_config
end

#diarization_speaker_countFixnum

If set, specifies the estimated number of speakers in the conversation. Defaults to '2'. Ignored unless enable_speaker_diarization is set to true. Note: Use diarization_config instead. Corresponds to the JSON property diarizationSpeakerCount

Returns:

  • (Fixnum)


823
824
825
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 823

def diarization_speaker_count
  @diarization_speaker_count
end

#enable_automatic_punctuationBoolean Also known as: enable_automatic_punctuation?

If 'true', adds punctuation to recognition result hypotheses. This feature is only available in select languages. Setting this for requests in other languages has no effect at all. The default 'false' value does not add punctuation to result hypotheses. Corresponds to the JSON property enableAutomaticPunctuation

Returns:

  • (Boolean)


831
832
833
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 831

def enable_automatic_punctuation
  @enable_automatic_punctuation
end

#enable_separate_recognition_per_channelBoolean Also known as: enable_separate_recognition_per_channel?

This needs to be set to true explicitly and audio_channel_count > 1 to get each channel recognized separately. The recognition result will contain a channel_tag field to state which channel that result belongs to. If this is not true, we will only recognize the first channel. The request is billed cumulatively for all channels recognized: audio_channel_count multiplied by the length of the audio. Corresponds to the JSON property enableSeparateRecognitionPerChannel

Returns:

  • (Boolean)


842
843
844
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 842

def enable_separate_recognition_per_channel
  @enable_separate_recognition_per_channel
end

#enable_speaker_diarizationBoolean Also known as: enable_speaker_diarization?

If 'true', enables speaker detection for each recognized word in the top alternative of the recognition result using a speaker_label provided in the WordInfo. Note: Use diarization_config instead. Corresponds to the JSON property enableSpeakerDiarization

Returns:

  • (Boolean)


850
851
852
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 850

def enable_speaker_diarization
  @enable_speaker_diarization
end

#enable_spoken_emojisBoolean Also known as: enable_spoken_emojis?

The spoken emoji behavior for the call If not set, uses default behavior based on model of choice If 'true', adds spoken emoji formatting for the request. This will replace spoken emojis with the corresponding Unicode symbols in the final transcript. If 'false', spoken emojis are not replaced. Corresponds to the JSON property enableSpokenEmojis

Returns:

  • (Boolean)


859
860
861
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 859

def enable_spoken_emojis
  @enable_spoken_emojis
end

#enable_spoken_punctuationBoolean Also known as: enable_spoken_punctuation?

The spoken punctuation behavior for the call If not set, uses default behavior based on model of choice e.g. command_and_search will enable spoken punctuation by default If 'true', replaces spoken punctuation with the corresponding symbols in the request. For example, "how are you question mark" becomes "how are you?". See https://cloud.google.com/speech-to-text/docs/ spoken-punctuation for support. If 'false', spoken punctuation is not replaced. Corresponds to the JSON property enableSpokenPunctuation

Returns:

  • (Boolean)


870
871
872
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 870

def enable_spoken_punctuation
  @enable_spoken_punctuation
end

#enable_word_confidenceBoolean Also known as: enable_word_confidence?

If true, the top result includes a list of words and the confidence for those words. If false, no word-level confidence information is returned. The default is false. Corresponds to the JSON property enableWordConfidence

Returns:

  • (Boolean)


878
879
880
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 878

def enable_word_confidence
  @enable_word_confidence
end

#enable_word_time_offsetsBoolean Also known as: enable_word_time_offsets?

If true, the top result includes a list of words and the start and end time offsets (timestamps) for those words. If false, no word-level time offset information is returned. The default is false. Corresponds to the JSON property enableWordTimeOffsets

Returns:

  • (Boolean)


886
887
888
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 886

def enable_word_time_offsets
  @enable_word_time_offsets
end

#encodingString

Encoding of audio data sent in all RecognitionAudio messages. This field is optional for FLAC and WAV audio files and required for all other audio formats. For details, see AudioEncoding. Corresponds to the JSON property encoding

Returns:

  • (String)


894
895
896
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 894

def encoding
  @encoding
end

#language_codeString

Required. The language of the supplied audio as a BCP-47 language tag. Example: "en-US". See Language Support for a list of the currently supported language codes. Corresponds to the JSON property languageCode

Returns:

  • (String)


902
903
904
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 902

def language_code
  @language_code
end

#max_alternativesFixnum

Maximum number of recognition hypotheses to be returned. Specifically, the maximum number of SpeechRecognitionAlternative messages within each SpeechRecognitionResult. The server may return fewer than max_alternatives. Valid values are 0-30. A value of 0 or 1 will return a maximum of one. If omitted, will return a maximum of one. Corresponds to the JSON property maxAlternatives

Returns:

  • (Fixnum)


911
912
913
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 911

def max_alternatives
  @max_alternatives
end

#metadataGoogle::Apis::SpeechV1p1beta1::RecognitionMetadata

Description of audio data to be recognized. Corresponds to the JSON property metadata



916
917
918
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 916

def 
  @metadata
end

#modelString

Which model to select for the given request. Select the model best suited to your domain to get best results. If a model is not explicitly specified, then we auto-select a model based on the parameters in the RecognitionConfig. * Model* Description latest_long Best for long form content like media or conversation. latest_short Best for short form content like commands or single shot directed speech. command_and_search Best for short queries such as voice commands or voice search. phone_call Best for audio that originated from a phone call (typically recorded at an 8khz sampling rate). video Best for audio that originated from video or includes multiple speakers. Ideally the audio is recorded at a 16khz or greater sampling rate. This is a premium model that costs more than the standard rate. default Best for audio that is not one of the specific audio models. For example, long-form audio. Ideally the audio is high-fidelity, recorded at a 16khz or greater sampling rate. medical_conversation Best for audio that originated from a conversation between a medical provider and patient. medical_dictation Best for audio that originated from dictation notes by a medical provider. Corresponds to the JSON property model

Returns:

  • (String)


936
937
938
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 936

def model
  @model
end

#profanity_filterBoolean Also known as: profanity_filter?

If set to true, the server will attempt to filter out profanities, replacing all but the initial character in each filtered word with asterisks, e.g. "f***" . If set to false or omitted, profanities won't be filtered out. Corresponds to the JSON property profanityFilter

Returns:

  • (Boolean)


943
944
945
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 943

def profanity_filter
  @profanity_filter
end

#sample_rate_hertzFixnum

Sample rate in Hertz of the audio data sent in all RecognitionAudio messages. Valid values are: 8000-48000. 16000 is optimal. For best results, set the sampling rate of the audio source to 16000 Hz. If that's not possible, use the native sample rate of the audio source (instead of re-sampling). This field is optional for FLAC and WAV audio files, but is required for all other audio formats. For details, see AudioEncoding. Corresponds to the JSON property sampleRateHertz

Returns:

  • (Fixnum)


954
955
956
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 954

def sample_rate_hertz
  @sample_rate_hertz
end

#speech_contextsArray<Google::Apis::SpeechV1p1beta1::SpeechContext>

Array of SpeechContext. A means to provide context to assist the speech recognition. For more information, see speech adaptation. Corresponds to the JSON property speechContexts



961
962
963
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 961

def speech_contexts
  @speech_contexts
end

#transcript_normalizationGoogle::Apis::SpeechV1p1beta1::TranscriptNormalization

Transcription normalization configuration. Use transcription normalization to automatically replace parts of the transcript with phrases of your choosing. For StreamingRecognize, this normalization only applies to stable partial transcripts (stability > 0.8) and final transcripts. Corresponds to the JSON property transcriptNormalization



969
970
971
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 969

def transcript_normalization
  @transcript_normalization
end

#use_enhancedBoolean Also known as: use_enhanced?

Set to true to use an enhanced model for speech recognition. If use_enhanced is set to true and the model field is not set, then an appropriate enhanced model is chosen if an enhanced model exists for the audio. If use_enhanced is true and an enhanced version of the specified model does not exist, then the speech is recognized using the standard version of the specified model. Corresponds to the JSON property useEnhanced

Returns:

  • (Boolean)


978
979
980
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 978

def use_enhanced
  @use_enhanced
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 986

def update!(**args)
  @adaptation = args[:adaptation] if args.key?(:adaptation)
  @alternative_language_codes = args[:alternative_language_codes] if args.key?(:alternative_language_codes)
  @audio_channel_count = args[:audio_channel_count] if args.key?(:audio_channel_count)
  @diarization_config = args[:diarization_config] if args.key?(:diarization_config)
  @diarization_speaker_count = args[:diarization_speaker_count] if args.key?(:diarization_speaker_count)
  @enable_automatic_punctuation = args[:enable_automatic_punctuation] if args.key?(:enable_automatic_punctuation)
  @enable_separate_recognition_per_channel = args[:enable_separate_recognition_per_channel] if args.key?(:enable_separate_recognition_per_channel)
  @enable_speaker_diarization = args[:enable_speaker_diarization] if args.key?(:enable_speaker_diarization)
  @enable_spoken_emojis = args[:enable_spoken_emojis] if args.key?(:enable_spoken_emojis)
  @enable_spoken_punctuation = args[:enable_spoken_punctuation] if args.key?(:enable_spoken_punctuation)
  @enable_word_confidence = args[:enable_word_confidence] if args.key?(:enable_word_confidence)
  @enable_word_time_offsets = args[:enable_word_time_offsets] if args.key?(:enable_word_time_offsets)
  @encoding = args[:encoding] if args.key?(:encoding)
  @language_code = args[:language_code] if args.key?(:language_code)
  @max_alternatives = args[:max_alternatives] if args.key?(:max_alternatives)
  @metadata = args[:metadata] if args.key?(:metadata)
  @model = args[:model] if args.key?(:model)
  @profanity_filter = args[:profanity_filter] if args.key?(:profanity_filter)
  @sample_rate_hertz = args[:sample_rate_hertz] if args.key?(:sample_rate_hertz)
  @speech_contexts = args[:speech_contexts] if args.key?(:speech_contexts)
  @transcript_normalization = args[:transcript_normalization] if args.key?(:transcript_normalization)
  @use_enhanced = args[:use_enhanced] if args.key?(:use_enhanced)
end