Class: Google::Apis::SpeechV1p1beta1::RecognitionMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpeechV1p1beta1::RecognitionMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/speech_v1p1beta1/classes.rb,
lib/google/apis/speech_v1p1beta1/representations.rb,
lib/google/apis/speech_v1p1beta1/representations.rb
Overview
Description of audio data to be recognized.
Instance Attribute Summary collapse
-
#audio_topic ⇒ String
Description of the content.
-
#industry_naics_code_of_audio ⇒ Fixnum
The industry vertical to which this speech recognition request most closely applies.
-
#interaction_type ⇒ String
The use case most closely describing the audio content to be recognized.
-
#microphone_distance ⇒ String
The audio type that most closely describes the audio being recognized.
-
#obfuscated_id ⇒ Fixnum
Obfuscated (privacy-protected) ID of the user, to identify number of unique users using the service.
-
#original_media_type ⇒ String
The original media the speech was recorded on.
-
#original_mime_type ⇒ String
Mime type of the original audio file.
-
#recording_device_name ⇒ String
The device used to make the recording.
-
#recording_device_type ⇒ String
The type of device the speech was recorded with.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RecognitionMetadata
constructor
A new instance of RecognitionMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RecognitionMetadata
Returns a new instance of RecognitionMetadata.
1070 1071 1072 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_topic ⇒ String
Description of the content. Eg. "Recordings of federal supreme court hearings
from 2012".
Corresponds to the JSON property audioTopic
1020 1021 1022 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1020 def audio_topic @audio_topic end |
#industry_naics_code_of_audio ⇒ Fixnum
The industry vertical to which this speech recognition request most closely
applies. This is most indicative of the topics contained in the audio. Use the
6-digit NAICS code to identify the industry vertical - see https://www.naics.
com/search/.
Corresponds to the JSON property industryNaicsCodeOfAudio
1028 1029 1030 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1028 def industry_naics_code_of_audio @industry_naics_code_of_audio end |
#interaction_type ⇒ String
The use case most closely describing the audio content to be recognized.
Corresponds to the JSON property interactionType
1033 1034 1035 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1033 def interaction_type @interaction_type end |
#microphone_distance ⇒ String
The audio type that most closely describes the audio being recognized.
Corresponds to the JSON property microphoneDistance
1038 1039 1040 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1038 def microphone_distance @microphone_distance end |
#obfuscated_id ⇒ Fixnum
Obfuscated (privacy-protected) ID of the user, to identify number of unique
users using the service.
Corresponds to the JSON property obfuscatedId
1044 1045 1046 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1044 def @obfuscated_id end |
#original_media_type ⇒ String
The original media the speech was recorded on.
Corresponds to the JSON property originalMediaType
1049 1050 1051 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1049 def original_media_type @original_media_type end |
#original_mime_type ⇒ String
Mime type of the original audio file. For example audio/m4a, audio/x-alaw-
basic, audio/mp3, audio/3gpp. A list of possible audio mime types is
maintained at http://www.iana.org/assignments/media-types/media-types.xhtml#
audio
Corresponds to the JSON property originalMimeType
1057 1058 1059 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1057 def original_mime_type @original_mime_type end |
#recording_device_name ⇒ String
The device used to make the recording. Examples 'Nexus 5X' or 'Polycom
SoundStation IP 6000' or 'POTS' or 'VoIP' or 'Cardioid Microphone'.
Corresponds to the JSON property recordingDeviceName
1063 1064 1065 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1063 def recording_device_name @recording_device_name end |
#recording_device_type ⇒ String
The type of device the speech was recorded with.
Corresponds to the JSON property recordingDeviceType
1068 1069 1070 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1068 def recording_device_type @recording_device_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1075 def update!(**args) @audio_topic = args[:audio_topic] if args.key?(:audio_topic) @industry_naics_code_of_audio = args[:industry_naics_code_of_audio] if args.key?(:industry_naics_code_of_audio) @interaction_type = args[:interaction_type] if args.key?(:interaction_type) @microphone_distance = args[:microphone_distance] if args.key?(:microphone_distance) @obfuscated_id = args[:obfuscated_id] if args.key?(:obfuscated_id) @original_media_type = args[:original_media_type] if args.key?(:original_media_type) @original_mime_type = args[:original_mime_type] if args.key?(:original_mime_type) @recording_device_name = args[:recording_device_name] if args.key?(:recording_device_name) @recording_device_type = args[:recording_device_type] if args.key?(:recording_device_type) end |