Class: Google::Apis::SpeechV1p1beta1::WordInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/speech_v1p1beta1/classes.rb,
lib/google/apis/speech_v1p1beta1/representations.rb,
lib/google/apis/speech_v1p1beta1/representations.rb

Overview

Word-specific information for recognized words.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WordInfo

Returns a new instance of WordInfo.



1547
1548
1549
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confidenceFloat

The confidence estimate between 0.0 and 1.0. A higher number indicates an estimated greater likelihood that the recognized words are correct. This field is set only for the top alternative of a non-streaming result or, of a streaming result where is_final=true. This field is not guaranteed to be accurate and users should not rely on it to be always provided. The default of 0.0 is a sentinel value indicating confidence was not set. Corresponds to the JSON property confidence

Returns:

  • (Float)


1505
1506
1507
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1505

def confidence
  @confidence
end

#end_timeString

Time offset relative to the beginning of the audio, and corresponding to the end of the spoken word. This field is only set if enable_word_time_offsets= true and only in the top hypothesis. This is an experimental feature and the accuracy of the time offset can vary. Corresponds to the JSON property endTime

Returns:

  • (String)


1513
1514
1515
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1513

def end_time
  @end_time
end

#speaker_labelString

Output only. A label value assigned for every unique speaker within the audio. This field specifies which speaker was detected to have spoken this word. For some models, like medical_conversation this can be actual speaker role, for example "patient" or "provider", but generally this would be a number identifying a speaker. This field is only set if enable_speaker_diarization = ' true' and only for the top alternative. Corresponds to the JSON property speakerLabel

Returns:

  • (String)


1523
1524
1525
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1523

def speaker_label
  @speaker_label
end

#speaker_tagFixnum

Output only. A distinct integer value is assigned for every speaker within the audio. This field specifies which one of those speakers was detected to have spoken this word. Value ranges from '1' to diarization_speaker_count. speaker_tag is set if enable_speaker_diarization = 'true' and only for the top alternative. Note: Use speaker_label instead. Corresponds to the JSON property speakerTag

Returns:

  • (Fixnum)


1532
1533
1534
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1532

def speaker_tag
  @speaker_tag
end

#start_timeString

Time offset relative to the beginning of the audio, and corresponding to the start of the spoken word. This field is only set if enable_word_time_offsets= true and only in the top hypothesis. This is an experimental feature and the accuracy of the time offset can vary. Corresponds to the JSON property startTime

Returns:

  • (String)


1540
1541
1542
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1540

def start_time
  @start_time
end

#wordString

The word corresponding to this set of information. Corresponds to the JSON property word

Returns:

  • (String)


1545
1546
1547
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1545

def word
  @word
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1552
1553
1554
1555
1556
1557
1558
1559
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1552

def update!(**args)
  @confidence = args[:confidence] if args.key?(:confidence)
  @end_time = args[:end_time] if args.key?(:end_time)
  @speaker_label = args[:speaker_label] if args.key?(:speaker_label)
  @speaker_tag = args[:speaker_tag] if args.key?(:speaker_tag)
  @start_time = args[:start_time] if args.key?(:start_time)
  @word = args[:word] if args.key?(:word)
end