Class: Google::Apis::SpeechV1p1beta1::LongRunningRecognizeMetadata
- Inherits:
-
Object
- Object
- Google::Apis::SpeechV1p1beta1::LongRunningRecognizeMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/speech_v1p1beta1/classes.rb,
lib/google/apis/speech_v1p1beta1/representations.rb,
lib/google/apis/speech_v1p1beta1/representations.rb
Overview
Describes the progress of a long-running LongRunningRecognize call. It is
included in the metadata field of the Operation returned by the
GetOperation call of the google::longrunning::Operations service.
Instance Attribute Summary collapse
-
#last_update_time ⇒ String
Time of the most recent processing update.
-
#output_config ⇒ Google::Apis::SpeechV1p1beta1::TranscriptOutputConfig
Specifies an optional destination for the recognition results.
-
#progress_percent ⇒ Fixnum
Approximate percentage of audio processed thus far.
-
#start_time ⇒ String
Time when the request was received.
-
#uri ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LongRunningRecognizeMetadata
constructor
A new instance of LongRunningRecognizeMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LongRunningRecognizeMetadata
Returns a new instance of LongRunningRecognizeMetadata.
402 403 404 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_update_time ⇒ String
Time of the most recent processing update.
Corresponds to the JSON property lastUpdateTime
378 379 380 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 378 def last_update_time @last_update_time end |
#output_config ⇒ Google::Apis::SpeechV1p1beta1::TranscriptOutputConfig
Specifies an optional destination for the recognition results.
Corresponds to the JSON property outputConfig
383 384 385 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 383 def output_config @output_config end |
#progress_percent ⇒ Fixnum
Approximate percentage of audio processed thus far. Guaranteed to be 100 when
the audio is fully processed and the results are available.
Corresponds to the JSON property progressPercent
389 390 391 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 389 def progress_percent @progress_percent end |
#start_time ⇒ String
Time when the request was received.
Corresponds to the JSON property startTime
394 395 396 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 394 def start_time @start_time end |
#uri ⇒ String
Output only. The URI of the audio file being transcribed. Empty if the audio
was sent as byte content.
Corresponds to the JSON property uri
400 401 402 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 400 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
407 408 409 410 411 412 413 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 407 def update!(**args) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @output_config = args[:output_config] if args.key?(:output_config) @progress_percent = args[:progress_percent] if args.key?(:progress_percent) @start_time = args[:start_time] if args.key?(:start_time) @uri = args[:uri] if args.key?(:uri) end |