Class: Google::Apis::SpeechV1p1beta1::SpeechRecognitionResult
- Inherits:
-
Object
- Object
- Google::Apis::SpeechV1p1beta1::SpeechRecognitionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/speech_v1p1beta1/classes.rb,
lib/google/apis/speech_v1p1beta1/representations.rb,
lib/google/apis/speech_v1p1beta1/representations.rb
Overview
A speech recognition result corresponding to a portion of the audio.
Instance Attribute Summary collapse
-
#alternatives ⇒ Array<Google::Apis::SpeechV1p1beta1::SpeechRecognitionAlternative>
May contain one or more recognition hypotheses (up to the maximum specified in
max_alternatives). -
#channel_tag ⇒ Fixnum
For multi-channel audio, this is the channel number corresponding to the recognized result for the audio from that channel.
-
#language_code ⇒ String
Output only.
-
#result_end_time ⇒ String
Time offset of the end of this result relative to the beginning of the audio.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SpeechRecognitionResult
constructor
A new instance of SpeechRecognitionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SpeechRecognitionResult
Returns a new instance of SpeechRecognitionResult.
1395 1396 1397 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternatives ⇒ Array<Google::Apis::SpeechV1p1beta1::SpeechRecognitionAlternative>
May contain one or more recognition hypotheses (up to the maximum specified in
max_alternatives). These alternatives are ordered in terms of accuracy, with
the top (first) alternative being the most probable, as ranked by the
recognizer.
Corresponds to the JSON property alternatives
1374 1375 1376 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1374 def alternatives @alternatives end |
#channel_tag ⇒ Fixnum
For multi-channel audio, this is the channel number corresponding to the
recognized result for the audio from that channel. For audio_channel_count = N,
its output values can range from '1' to 'N'.
Corresponds to the JSON property channelTag
1381 1382 1383 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1381 def channel_tag @channel_tag end |
#language_code ⇒ String
Output only. The BCP-47
language tag of the language in this result. This language code was detected
to have the most likelihood of being spoken in the audio.
Corresponds to the JSON property languageCode
1388 1389 1390 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1388 def language_code @language_code end |
#result_end_time ⇒ String
Time offset of the end of this result relative to the beginning of the audio.
Corresponds to the JSON property resultEndTime
1393 1394 1395 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1393 def result_end_time @result_end_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1400 1401 1402 1403 1404 1405 |
# File 'lib/google/apis/speech_v1p1beta1/classes.rb', line 1400 def update!(**args) @alternatives = args[:alternatives] if args.key?(:alternatives) @channel_tag = args[:channel_tag] if args.key?(:channel_tag) @language_code = args[:language_code] if args.key?(:language_code) @result_end_time = args[:result_end_time] if args.key?(:result_end_time) end |